@@ -25,26 +25,29 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
   end
 
   def self.get_keystone_puppet_credentials
-    auth_keys = ['auth_url', 'project_name', 'username',
-                 'password']
-    conf = keystone_puppet_conf
-    if conf and conf['keystone_authtoken'] and
-        auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
-      creds = Hash[ auth_keys.map \
-                   { |k| [k, conf['keystone_authtoken'][k].strip] } ]
+    auth_keys = ['auth_url', 'project_name', 'username', 'password']
+
+    conf = keystone_puppet_conf ? keystone_puppet_conf['keystone_authtoken'] : {}
+
+    if conf and auth_keys.all?{|k| !conf[k].nil?}
+      creds = Hash[ auth_keys.map { |k| [k, conf[k].strip] } ]
+
       if conf['project_domain_name']
         creds['project_domain_name'] = conf['project_domain_name']
       else
         creds['project_domain_name'] = 'Default'
       end
+
       if conf['user_domain_name']
         creds['user_domain_name'] = conf['user_domain_name']
       else
         creds['user_domain_name'] = 'Default'
       end
-      if conf['keystone_authtoken']['region_name']
-        creds['region_name'] = conf['keystone_authtoken']['region_name']
+
+      if conf['region_name']
+        creds['region_name'] = conf['region_name']
       end
+
       return creds
     else
       raise(Puppet::Error, "File: #{conf_filename} does not contain all " +
@@ -74,7 +77,7 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
       .find('Keystone_config/identity/default_domain_id')
     if default_domain_from_conf[:ensure] == :present
       # get from ini file
-      default_domain_from_conf[:value]
+      default_domain_from_conf[:value][0]
     else
       nil
     end
@@ -139,8 +142,11 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
     id_str = "#{name}_#{domain_name}"
     unless @users_name.keys.include?(id_str)
       user = fetch_user(name, domain_name)
-      err("Could not find user with name [#{name}] and domain [#{domain_name}]") unless user
-      @users_name[id_str] = user[:id]
+      if user && user.key?(:id)
+        @users_name[id_str] = user[:id]
+      else
+        err("Could not find user with name [#{name}] and domain [#{domain_name}]")
+      end
     end
     @users_name[id_str]
   end
@@ -150,8 +156,11 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
     id_str = "#{name}_#{domain_name}"
     unless @projects_name.keys.include?(id_str)
       project = fetch_project(name, domain_name)
-      err("Could not find project with name [#{name}] and domain [#{domain_name}]") unless project
-      @projects_name[id_str] = project[:id]
+      if project && project.key?(:id)
+        @projects_name[id_str] = project[:id]
+      else
+        err("Could not find project with name [#{name}] and domain [#{domain_name}]")
+      end
     end
     @projects_name[id_str]
   end
@@ -159,12 +168,19 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
   def self.domain_name_from_id(id)
     unless @domain_hash
       list = request('domain', 'list')
-      @domain_hash = Hash[list.collect{|domain| [domain[:id], domain[:name]]}]
+      if list.nil?
+        err("Could not list domains")
+      else
+        @domain_hash = Hash[list.collect{|domain| [domain[:id], domain[:name]]}]
+      end
     end
     unless @domain_hash.include?(id)
-      name = request('domain', 'show', id)[:name]
-      err("Could not find domain with id [#{id}]") unless name
-      @domain_hash[id] = name
+      domain = request('domain', 'show', id)
+      if domain && domain.key?(:name)
+        @domain_hash[id] = domain[:name]
+      else
+        err("Could not find domain with id [#{id}]")
+      end
     end
     @domain_hash[id]
   end
@@ -175,9 +191,12 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
       @domain_hash_name = Hash[list.collect{|domain| [domain[:name], domain[:id]]}]
     end
     unless @domain_hash_name.include?(name)
-      id = request('domain', 'show', name)[:id]
-      err("Could not find domain with name [#{name}]") unless id
-      @domain_hash_name[name] = id
+      domain = request('domain', 'show', name)
+      if domain && domain.key?(:id)
+        @domain_hash_name[name] = domain[:id]
+      else
+        err("Could not find domain with name [#{name}]")
+      end
     end
     @domain_hash_name[name]
   end
@@ -244,13 +263,7 @@ class Puppet::Provider::Keystone < Puppet::Provider::Openstack
       @credentials.project_domain_name = keystone_puppet_credentials['project_domain_name']
     end
     raise error unless @credentials.set?
-    begin
-      Puppet::Provider::Openstack.request(service, action, properties, @credentials)
-    rescue Puppet::ExecutionFailure, Puppet::Error::OpenstackUnauthorizedError
-      # openstackclient < 4.0.0 does not support --os-endpoint and requires --os-url
-      @credentials.url = auth_endpoint
-      Puppet::Provider::Openstack.request(service, action, properties, @credentials)
-    end
+    Puppet::Provider::Openstack.request(service, action, properties, @credentials)
   end
 
   def self.set_domain_for_name(name, domain_name)
